DATA_DIR = "/gnome/share"
LIB_DIR = "/gnome/lib"
VERSION = "2.23.2"
PACKAGE = "gnome-applets"
PYTHONDIR = "/gnome/lib/python2.5/site-packages"
GETTEXT_PACKAGE = "gnome-applets-2.0"
GNOMELOCALEDIR = "/gnome/share/locale"
BUILDERDIR = "/gnome/share/gnome-applets/builder"
